@@ -44,11 +44,14 @@ func (t *consoleTitle) getTemplateText() string {
 		Template: t.config.ConsoleTitleTemplate,
 		Env:      t.env,
 	}
-	return template.renderPlainContextTemplate(nil)
+	if text, err := template.render(); err == nil {
+		return text
+	}
+	return ""
 }
 
 func (t *consoleTitle) getPwd() string {
-	pwd := t.env.getcwd()
+	pwd := t.env.pwd()
 	pwd = strings.Replace(pwd, t.env.homeDir(), "~", 1)
 	return pwd
 }
