@@ -66,6 +66,7 @@ type args struct {
 	Command        *string
 	PrintTransient *bool
 	Plain          *bool
+	CachePath      *bool
 }
 
 func main() {
@@ -170,6 +171,10 @@ func main() {
 			"plain",
 			false,
 			"Print a plain prompt without ANSI"),
+		CachePath: flag.Bool(
+			"cache-path",
+			false,
+			"Print the location of the cache"),
 	}
 	flag.Parse()
 	if *args.Version {
@@ -187,6 +192,10 @@ func main() {
 		fmt.Print(time.Now().UnixNano() / 1000000)
 		return
 	}
+	if *args.CachePath {
+		fmt.Print(env.getCachePath())
+		return
+	}
 	if *args.Init {
 		init := initShell(*args.Shell, *args.Config)
 		fmt.Print(init)
@@ -327,18 +336,9 @@ func getConsoleBackgroundColor(env Environment, backgroundColorTemplate string)
 	if len(backgroundColorTemplate) == 0 {
 		return backgroundColorTemplate
 	}
-	context := struct {
-		Env map[string]string
-	}{
-		Env: map[string]string{},
-	}
-	matches := findAllNamedRegexMatch(templateEnvRegex, backgroundColorTemplate)
-	for _, match := range matches {
-		context.Env[match["ENV"]] = env.getenv(match["ENV"])
-	}
 	template := &textTemplate{
 		Template: backgroundColorTemplate,
-		Context:  context,
+		Context:  nil,
 		Env:      env,
 	}
 	text, err := template.render()
