@@ -18,7 +18,12 @@ func TestConsoleBackgroundColorTemplate(t *testing.T) {
 
 	for _, tc := range cases {
 		env := new(MockedEnvironment)
-		env.On("getenv", "TERM_PROGRAM").Return(tc.Term)
+		env.On("templateCache").Return(&templateCache{
+			Env: map[string]string{
+				"TERM_PROGRAM": tc.Term,
+			},
+		})
+		env.onTemplate()
 		color := getConsoleBackgroundColor(env, "{{ if eq \"vscode\" .Env.TERM_PROGRAM }}#123456{{end}}")
 		assert.Equal(t, tc.Expected, color, tc.Case)
 	}
