@@ -9,8 +9,8 @@ import (
 )
 
 type executiontime struct {
-	props properties
-	env   environmentInfo
+	props Properties
+	env   Environment
 
 	FormattedMs string
 	Ms          int64
@@ -63,7 +63,7 @@ func (t *executiontime) string() string {
 	return t.FormattedMs
 }
 
-func (t *executiontime) init(props properties, env environmentInfo) {
+func (t *executiontime) init(props Properties, env Environment) {
 	t.props = props
 	t.env = env
 }
