@@ -1,8 +1,8 @@
 package main
 
 type root struct {
-	props properties
-	env   environmentInfo
+	props Properties
+	env   Environment
 }
 
 const (
@@ -18,7 +18,7 @@ func (rt *root) string() string {
 	return rt.props.getString(RootIcon, "\uF0E7")
 }
 
-func (rt *root) init(props properties, env environmentInfo) {
+func (rt *root) init(props Properties, env Environment) {
 	rt.props = props
 	rt.env = env
 }
