@@ -16,8 +16,9 @@ func bootStrapTerraformTest(args *terraformArgs) *terraform {
 	env := new(MockedEnvironment)
 	env.On("hasCommand", "terraform").Return(args.hasTfCommand)
 	env.On("hasFolder", "/.terraform").Return(args.hasTfFolder)
-	env.On("getcwd", nil).Return("")
+	env.On("pwd").Return("")
 	env.On("runCommand", "terraform", []string{"workspace", "show"}).Return(args.workspaceName, nil)
+	env.onTemplate()
 	k := &terraform{
 		env:   env,
 		props: properties{},
