@@ -6,8 +6,8 @@ import (
 )
 
 type ytm struct {
-	props  properties
-	env    environmentInfo
+	props  Properties
+	env    Environment
 	status playStatus
 	artist string
 	track  string
@@ -39,7 +39,7 @@ func (y *ytm) enabled() bool {
 	return err == nil
 }
 
-func (y *ytm) init(props properties, env environmentInfo) {
+func (y *ytm) init(props Properties, env Environment) {
 	y.props = props
 	y.env = env
 }
@@ -86,7 +86,7 @@ func (y *ytm) setStatus() error {
 	// https://github.com/ytmdesktop/ytmdesktop/wiki/Remote-Control-API
 	url := y.props.getString(APIURL, "http://127.0.0.1:9863")
 	httpTimeout := y.props.getInt(APIURL, DefaultHTTPTimeout)
-	body, err := y.env.doGet(url+"/query", httpTimeout)
+	body, err := y.env.HTTPRequest(url+"/query", httpTimeout)
 	if err != nil {
 		return err
 	}
